@@ -76,8 +76,8 @@ void gl_journal_set_start_position (GlJournal *journal, guint64 until_timestamp)
 GArray * gl_journal_get_boot_ids (GlJournal *journal);
 GlJournalEntry * gl_journal_previous (GlJournal *journal);
 GlJournal * gl_journal_new (void);
-gchar * gl_journal_get_current_boot_time (GlJournal *journal,
-                                          const gchar *boot_match);
+gchar * gl_journal_get_boot_time (GlJournal *journal,
+                                  const gchar *boot_match);
 
 guint64                 gl_journal_entry_get_timestamp                  (GlJournalEntry *entry);
 const gchar *           gl_journal_entry_get_message                    (GlJournalEntry *entry);
